@@ -1,6 +1,7 @@
 """Unicode Properties from Unicode version 12.1.0 (autogen)."""
+from typing import Dict
 
-unicode_alias = {
+unicode_alias: Dict[str, Dict[str, str]] = {
     "_": {
         "age": "age",
         "bc": "bidiclass",
